/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: _dbg_entrypoints
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class _dbg_entrypoints {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int _ImagehlpApiVersionOffset_;
	public static final int _StackWalk64Offset_;
	public static final int _SymCleanupOffset_;
	public static final int _SymFromAddrOffset_;
	public static final int _SymFunctionTableAccess64Offset_;
	public static final int _SymGetLineFromAddr64Offset_;
	public static final int _SymGetModuleBase64Offset_;
	public static final int _SymGetModuleInfo64Offset_;
	public static final int _SymGetOptionsOffset_;
	public static final int _SymInitializeWOffset_;
	public static final int _SymSetOptionsOffset_;
	public static final int _hDbgHelpLibOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		_ImagehlpApiVersionOffset_ = 0;
		_StackWalk64Offset_ = 0;
		_SymCleanupOffset_ = 0;
		_SymFromAddrOffset_ = 0;
		_SymFunctionTableAccess64Offset_ = 0;
		_SymGetLineFromAddr64Offset_ = 0;
		_SymGetModuleBase64Offset_ = 0;
		_SymGetModuleInfo64Offset_ = 0;
		_SymGetOptionsOffset_ = 0;
		_SymInitializeWOffset_ = 0;
		_SymSetOptionsOffset_ = 0;
		_hDbgHelpLibOffset_ = 0;
	}

}
